@@ -1,20 +1,12 @@
 # REEXPORT FROM ARKHE
 
-#' @importFrom kairos get_order
+#' @importFrom arkhe bootstrap
 #' @export
-kairos::get_order
+arkhe::bootstrap
 
-#' @importFrom kairos permute
+#' @importFrom arkhe jackknife
 #' @export
-kairos::permute
-
-#' @importFrom kairos seriate_average
-#' @export
-kairos::seriate_average
-
-#' @importFrom kairos seriate_rank
-#' @export
-kairos::seriate_rank
+arkhe::jackknife
 
 #' @importFrom arkhe replace_NA
 #' @export
@@ -31,7 +23,3 @@ arkhe::remove_NA
 #' @importFrom arkhe remove_zero
 #' @export
 arkhe::remove_zero
-
-#' @importFrom arkhe remove_empty
-#' @export
-arkhe::remove_empty
