@@ -2,6 +2,17 @@
 #' @include AllClasses.R AllGenerics.R
 NULL
 
+expected <- function(x) {
+  m <- nrow(x)
+  p <- ncol(x)
+
+  column_total <- matrix(colSums(x), nrow = m, ncol = p, byrow = TRUE)
+  row_total <- matrix(rowSums(x), nrow = m, ncol = p, byrow = FALSE)
+  grand_total <- sum(x)
+
+  column_total * row_total / grand_total
+}
+
 #' @export
 #' @rdname resample
 #' @aliases resample,numeric-method
@@ -20,78 +31,6 @@ setMethod(
   }
 )
 
-expected <- function(x) {
-  m <- nrow(x)
-  p <- ncol(x)
-
-  column_total <- matrix(colSums(x), nrow = m, ncol = p, byrow = TRUE)
-  row_total <- matrix(rowSums(x), nrow = m, ncol = p, byrow = FALSE)
-  grand_total <- sum(x)
-
-  column_total * row_total / grand_total
-}
-
-#' @export
-#' @rdname independance
-#' @aliases eppm,matrix-method
-setMethod(
-  f = "eppm",
-  signature = signature(object = "matrix"),
-  definition = function(object) {
-    # Independance
-    values <- expected(object)
-
-    # Threshold
-    threshold <- (object - values) / rowSums(object)
-    threshold[threshold < 0] <- 0
-
-    dimnames(threshold) <- dimnames(object)
-    threshold
-  }
-)
-
-#' @export
-#' @rdname independance
-#' @aliases eppm,data.frame-method
-setMethod(
-  f = "eppm",
-  signature = signature(object = "data.frame"),
-  definition = function(object) {
-    object <- data.matrix(object)
-    methods::callGeneric(object)
-  }
-)
-
-#' @export
-#' @rdname independance
-#' @aliases pvi,matrix-method
-setMethod(
-  f = "pvi",
-  signature = signature(object = "matrix"),
-  definition = function(object) {
-    # Independance
-    values <- expected(object)
-
-    # Threshold
-    threshold <- object / values
-
-    dimnames(threshold) <- dimnames(object)
-    threshold
-  }
-)
-
-#' @export
-#' @rdname independance
-#' @aliases pvi,data.frame-method
-setMethod(
-  f = "pvi",
-  signature = signature(object = "data.frame"),
-  definition = function(object) {
-    object <- data.matrix(object)
-    methods::callGeneric(object)
-  }
-)
-
 #' Binomial Coefficient
 #'
 #' Computes the number of `k`-combinations from a given set of `n` elements
